var LabEnvDbExp = function()
{
	var labenvdbexp = {};
	var debug = 1;

	// Page initialization
	labenvdbexp.initPage = function()
	{
		previewTitle = Doc.element('previewTitle');
		previewList = Doc.element('previewList');

		// Step 1
		Events.addEventHandler('fromDate', 'blur', labenvdbexp.fromDateTimeOnChange);
		Events.addEventHandler('fromTime', 'blur', labenvdbexp.fromDateTimeOnChange);
		Events.addEventHandler('toDate', 'blur', labenvdbexp.toDateTimeOnChange);
		Events.addEventHandler('toTime', 'blur', labenvdbexp.toDateTimeOnChange);

		// Navigation
		Buttons.addClickHandler('goexport', labenvdbexp.goExport);
		Buttons.addClickHandler('gopreview', labenvdbexp.goPreview);

		// Create lab sensor menu from configuration data
		labenvdbexp.createSensorMenu();

		Doc.show('step-1');
		Doc.show('gopreview');
		Doc.show('goexport');
	}

	labenvdbexp.createSensorMenu = function()
	{
		// Get lab sensor configurations JSON object with AJAX
		var url = '../LabEnvironment.servlet?ID='+App.getSessionId();
		url += '&cmd=GetLabSensorConfigList';

		Wizard.asyncJsonRequest(url, labenvdbexp.createSensorMenu2);
	}

	labenvdbexp.createSensorMenu2 = function(response)
	{
		Doc.show('navigation');
		if (response.status != 'ok')
		{
			setFatalError(response.message);
			return false;
		}
		// Get sensor configurations information from the AJAX response
		var labSensorConfigList = response.labSensorConfigList;
		if (labSensorConfigList != null)
		{
			// Construct lab sensor menu from JSON data
			var sensorSelect = document.getElementById('sensorSelectId');
			for (var i=0; i < labSensorConfigList.length; i++)
			{
				// Get URL and name for lab sensor number 'i'
				var labSensorConfig = labSensorConfigList[i];
				var sensorUrl = labSensorConfig['url'];
				var sensorName = labSensorConfig['name'];
				// Create and add new option element to select menu
				var optionEl = document.createElement('option');
				optionEl.setAttribute('value',sensorUrl);
				optionEl.innerHTML = sensorName;
				sensorSelect.appendChild(optionEl);
			}
		}
	}

	labenvdbexp.goPreview = function()
	{
		labenvdbexp.doExport(true);
	}

	labenvdbexp.goExport = function()
	{
		labenvdbexp.doExport(false);
	}

	labenvdbexp.doExport = function(preview)
	{
		var frm = document.forms['labenv'];
		var url = '../LabEnvironment.servlet?ID='+App.getSessionId();
		url += '&cmd=LabEnvironmentDatabaseQuery';
		if (frm.sensorSelect.value != null) url += '&sensorurl='+frm.sensorSelect.value;
		var sensorUrlText = frm.sensorSelect[frm.sensorSelect.selectedIndex].text;
		url += '&sensorname='+sensorUrlText;
		url += '&fdate='+frm.fromDate.value;
		url += '&ftime='+frm.fromTime.value;
		url += '&tdate='+frm.toDate.value;
		url += '&ttime='+frm.toTime.value;
		if (frm.displayIndexSelect.value != null) url += '&displayindex='+frm.displayIndexSelect.value;
		url += '&returntype=export';
		if (preview) 
		{
			var previewTitle = document.getElementById('previewTitle');
			var previewList = document.getElementById('previewList');
		
			Doc.hide('previewWrapper');
			previewTitle.innerHTML = 'Working...';
			previewList.innerHTML = '';
		
			url += '&preview=1';

			Wizard.showLoadingAnimation('Working...');
			Doc.hide('navigation');
			Wizard.asyncJsonRequest(url, labenvdbexp.onPreviewLoaded);
		}
		else
		{
			window.location = url;		
		}
	}
	
	labenvdbexp.onPreviewLoaded = function(response)
	{
		Doc.show('navigation');
		var frm = document.forms['labenv'];
		var allLines = response.split('\n');
		var numLines = allLines.length - 2; // First line is a header line
		
		var html = '<tr><th>'+allLines[0].replace(/\t/g, '</th><th>')+'</th></tr>';
		for (var i = 1 ; i <= numLines; i++)
		{
			var line = allLines[i];
			var cols = line.split(/\t/);
			var rowClass = '';
			html += '<tr class="'+rowClass+'"><td>'+cols.join('</td><td>')+'</td></tr>';
		}

		var sensorUrlText = frm.sensorSelect[frm.sensorSelect.selectedIndex].text;
		previewTitle.innerHTML = 'Sensor - ' + sensorUrlText;
		previewList.innerHTML = '<table>'+html+'</table>';
		Doc.show('previewWrapper');
	}

	labenvdbexp.addEventHandlers = function(elements, eventName, handler)
	{
		for (var i = 0; i < elements.length; i++)
		{
			Events.addEventHandler(elements[i], eventName, handler);
		}
	}

	labenvdbexp.fromDateTimeOnChange = function()
	{
		var frm = document.forms['labenv'];
		var todaysDate = new Date();
		fromDateIsValid = false;
		setInputStatus('fromDate', '', '');
	
		var fromDate = frm.fromDate.value;
		var fromTime = frm.fromTime.value;
	
		if (fromDate != '' || fromTime != '')
		{
			// Auto-fill the date if it's only given with 4(MMdd) or 6(yyMMdd) digits.
			fromDate = autoFillDate(fromDate);
			frm.fromDate.value = fromDate;

			fromTime = autoFillTime(fromTime);
			frm.fromTime.value = fromTime;
		
			if (!Dates.isDate(fromDate, 'yyyyMMdd'))
			{
				setInputStatus('fromDate', 'Not a valid date', 'invalid');
				return;
			}		
		
			if (!Dates.isDate(fromDate + ' ' + fromTime, 'yyyyMMdd HHmm'))
			{
				if (fromDate != '') setInputStatus('fromDate', 'Not a valid time (if time unknown, also leave date field blank)', 'invalid');
				return;
			}
			setInputStatus('fromDate', '', 'valid');
		}
		fromDateIsValid = true;
		toDateTimeOnChange();
	}

	labenvdbexp.toDateTimeOnChange = function()
	{
		var frm = document.forms['labenv'];
		var todaysDate = new Date();
		toDateIsValid = false;
		setInputStatus('toDate', '', '');
	
		var toDate = frm.toDate.value;
		var toTime = frm.toTime.value;
	
		if (toDate != '' || toTime != '')
		{
			// Auto-fill the date if it's only given with 4(MMdd) or 6(yyMMdd) digits.
			toDate = autoFillDate(toDate);
			frm.toDate.value = toDate;

			toTime = autoFillTime(toTime);
			frm.toTime.value = toTime;
		
			if (!Dates.isDate(toDate, 'yyyyMMdd'))
			{
				setInputStatus('toDate', 'Not a valid date', 'invalid');
				return;
			}		
		
			if (!Dates.isDate(toDate + ' ' + toTime, 'yyyyMMdd HHmm'))
			{
				if (toDate != '') setInputStatus('toDate', 'Not a valid time (if time unknown, also leave date field blank)', 'invalid');
				return;
			}
			setInputStatus('toDate', '', 'valid');
		}
		toDateIsValid = true;
	}
	
	return labenvdbexp;
}();

Doc.onLoad(LabEnvDbExp.initPage);
